==> aroundme_0_6_0.tar.tgz: aroundme_0_6_0/aroundme/language/1/barnraiser_01/nlt_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');


//SECTION TITLES
$lang['hdr_menu'] = 							"menu";
$lang['hdr_newsletters'] = 						"newsletters";


//ERROR
$lang['err_no_newsletters'] = 					"Sorry, there are no newsletters.";


// OPTIONS
$lang['txt_my_options'] = 						"my options";
$lang['txt_group_options'] = 					"group options";
$lang['txt_option_list'] = 						"list";
$lang['txt_option_edit'] = 						"resend";
$lang['txt_option_add'] = 						"add node newsletter";
$lang['txt_option_group_add'] = 				"add group newsletter";
$lang['txt_group_link'] = 						"This blog is from the group";

?>

==> aroundme_0_6_3.tar.tgz: aroundme_0_6_3/aroundme/language/1/barnraiser_01/nlt_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');


//SECTION TITLES
$lang['hdr_menu'] = 							"menu";
$lang['hdr_newsletters'] = 						"newsletters";


//ERROR
$lang['err_no_newsletters'] = 					"Sorry, there are no newsletters.";


// HREF
$lang['href_list'] = 						"list newsletters";
$lang['href_list_group'] = 					"list group newsletters";
$lang['href_edit'] = 						"resend";
$lang['href_add_newsletter'] = 				"send a newsletter";
$lang['href_add_group_newsletter'] = 		"send a group newsletter";

?>
